# Network Importer

The network importer is a tool/library to analyze and/or synchronize an existing network with a Network Source of Truth (SOT), it's designed to be idempotent and by default it's only showing the difference between the running network and the remote SOT.

The main use cases for the network importer:

- Import an existing network into a SOT (Nautobot or NetBox) as a first step to automate a brownfield network
- Check the differences between the running network and the Source of Truth

## Quick Start

- [Getting Started](docs/getting_started.md)
- [Configuration file](docs/configuration.md)
- [Supported Features and Architecture](docs/architecture.md)
- [Extensibility](docs/extensibility.md)
- [Upgrade procedure](docs/upgrade.md)

## Questions

For any questions or comments, please feel free to open an issue or swing by the [networktocode slack channel](https://networktocode.slack.com/). (channel #networktocode)

Sign up [here](http://slack.networktocode.com/)
